%-------------------------------------------------------------------------%
% LONG CABLE:                                                             %
% Optical Transfer functions for Dual PD Amp -- measures the amplitude and
%   phase between the input and output signal through the board from      % 
%   the OZ Optics fiber couled laser                                      %
% Data from SR785                                                         %
%                                                                         %
%-------------------------------------------------------------------------%

%% Modulation Noise
data110 = importdata('SRS110.mat');

% shift to zero dB
maxdb = max(data110(:,2));
data110(:,2) = data110(:,2)-maxdb;


%% Board Side B:

% D0: Off, D1: Off (0dB)
data119 = importdata('SRS119.mat');
% D0: On, D1: Off (10dB)
data120 = importdata('SRS120.mat');
% D0: On, D1: On (20dB)
data121 = importdata('SRS121.mat');
% D0: Off, D1: On (30dB)
data122 = importdata('SRS122.mat');


% Account for laser modulation
data119(:,2) = data119(:,2) - data110(:,2);
data120(:,2) = data120(:,2) - data110(:,2);
data121(:,2) = data121(:,2) - data110(:,2);
data122(:,2) = data122(:,2) - data110(:,2);
data119(:,3) = data119(:,3) - data110(:,3);
data120(:,3) = data120(:,3) - data110(:,3);
data121(:,3) = data121(:,3) - data110(:,3);
data122(:,3) = data122(:,3) - data110(:,3);

%% Board Side A:

% D0: Off, D1: Off (0dB)
data123 = importdata('SRS123.mat');
% D0: On, D1: Off (10dB)
data124 = importdata('SRS124.mat');
% D0: On, D1: On (20dB)
data125 = importdata('SRS125.mat');
% D0: Off, D1: On (30dB)
data126 = importdata('SRS126.mat');

% Account for laser modulation
data123(:,2) = data123(:,2) - data110(:,2);
data124(:,2) = data124(:,2) - data110(:,2);
data125(:,2) = data125(:,2) - data110(:,2);
data126(:,2) = data126(:,2) - data110(:,2);
data123(:,3) = data123(:,3) - data110(:,3);
data124(:,3) = data124(:,3) - data110(:,3);
data125(:,3) = data125(:,3) - data110(:,3);
data126(:,3) = data126(:,3) - data110(:,3);

%% Side B Plots
figure(1);
subplot(2,1,1)
semilogx(data119(126:800,1), data119(126:800,2),data120(126:800,1), data120(126:800,2),data121(126:800,1), data121(126:800,2),data122(126:800,1), data122(126:800,2));
legend('-- gain', '+- gain', '++ gain', '-+ gain');
title('Amplitude Optical Transfer Functions of side B with long cable');
xlabel('Hz');
ylabel('dB');
grid;
subplot(2,1,2)
semilogx(data119(126:800,1), unwrap(data119(126:800,3)),data120(126:800,1), unwrap(data120(126:800,3)),data121(126:800,1), unwrap(data121(126:800,3)),data122(126:800,1), unwrap(data122(126:800,3)));
legend('-- gain', '+- gain', '++ gain', '-+ gain');
title('Phase Optical Transfer Functions of side B with long cable');
xlabel('Hz');
ylabel('Deg');
grid;


%% Side A Plot
figure (2)
subplot(2,1,1)
semilogx(data123(112:800,1), data123(112:800,2),data124(112:800,1), data124(112:800,2),data125(112:800,1), data125(112:800,2),data126(112:800,1), data126(112:800,2));
legend('-- gain', '+- gain', '++ gain', '-+ gain');
title('Amplitude Optical Transfer Functions of side A with long cable');
xlabel('Hz');
ylabel('dB');
grid;
subplot(2,1,2)
legend('-- gain', '+- gain', '++ gain', '-+ gain');
semilogx(data123(112:800,1), unwrap(data123(112:800,3)),data124(112:800,1), unwrap(data124(112:800,3)),data125(112:800,1), unwrap(data125(112:800,3)),data126(112:800,1), unwrap(data126(112:800,3)));
title('Phase Optical Transfer Functions of side A with long cable');
xlabel('Hz');
ylabel('Deg');
grid;

%% Comparison of Long and Short Cable Transfer Function
% data pulled from Tranfer Function folder (TF.m)

figure(3)
subplot(2,1,1)
semilogx(data114(112:800,1), data114(112:800,2),data126(112:800,1), (data126(112:800,2)));
legend('Short Cable', 'Long Cable');
title('Amplitude Transfer Functions for -x gain settings of side A');
xlabel('Hz');
ylabel('dB');
grid;
subplot(2,1,2)
semilogx(data114(112:800,1), unwrap(data114(112:800,3)),data126(112:800,1), unwrap(data126(112:800,3)));
legend('Short Cable', 'Long Cable');
title('Phase Transfer Functions for -x gain settings of side A');
xlabel('Hz');
ylabel('Deg');
grid;
